All language subtitles for The Valley S02E12

af Afrikaans
ak Akan
sq Albanian
am Amharic
ar Arabic
hy Armenian
az Azerbaijani
eu Basque
be Belarusian
bem Bemba
bn Bengali
bh Bihari
bs Bosnian
br Breton
bg Bulgarian
km Cambodian
ca Catalan
ceb Cebuano
chr Cherokee
ny Chichewa
zh-CN Chinese (Simplified)
zh-TW Chinese (Traditional)
co Corsican
hr Croatian
cs Czech
da Danish
nl Dutch
en English
eo Esperanto
et Estonian
ee Ewe
fo Faroese
tl Filipino
fi Finnish
fr French
fy Frisian
gaa Ga
gl Galician
ka Georgian
de German
el Greek
gn Guarani
gu Gujarati
ht Haitian Creole
ha Hausa
haw Hawaiian
iw Hebrew
hi Hindi
hmn Hmong
hu Hungarian
is Icelandic
ig Igbo
id Indonesian
ia Interlingua
ga Irish
it Italian
ja Japanese
jw Javanese
kn Kannada
kk Kazakh
rw Kinyarwanda
rn Kirundi
kg Kongo
ko Korean
kri Krio (Sierra Leone)
ku Kurdish
ckb Kurdish (Soranî)
ky Kyrgyz
lo Laothian
la Latin
lv Latvian
ln Lingala
lt Lithuanian
loz Lozi
lg Luganda
ach Luo
lb Luxembourgish
mk Macedonian
mg Malagasy
ms Malay
ml Malayalam
mt Maltese
mi Maori
mr Marathi
mfe Mauritian Creole
mo Moldavian
mn Mongolian
my Myanmar (Burmese)
sr-ME Montenegrin
ne Nepali
pcm Nigerian Pidgin
nso Northern Sotho
no Norwegian
nn Norwegian (Nynorsk)
oc Occitan
or Oriya
om Oromo
ps Pashto
fa Persian
pl Polish
pt-BR Portuguese (Brazil)
pt Portuguese (Portugal)
pa Punjabi
qu Quechua
ro Romanian
rm Romansh
nyn Runyakitara
ru Russian
sm Samoan
gd Scots Gaelic
sr Serbian
sh Serbo-Croatian
st Sesotho
tn Setswana
crs Seychellois Creole
sn Shona
sd Sindhi
si Sinhalese
sk Slovak
sl Slovenian
so Somali
es Spanish
es-419 Spanish (Latin American) Download
su Sundanese
sw Swahili
sv Swedish
tg Tajik
ta Tamil
tt Tatar
te Telugu
th Thai
ti Tigrinya
to Tonga
lua Tshiluba
tum Tumbuka
tr Turkish
tk Turkmen
tw Twi
ug Uighur
uk Ukrainian
ur Urdu
uz Uzbek
vi Vietnamese
cy Welsh
wo Wolof
xh Xhosa
yi Yiddish
yo Yoruba
zu Zulu

Original subtitles

Previously on "The Valley"...

I know we were talking about taking, like,

an end of the summer trip, and we wanted to do Hawaii.

-Whoo-whoo-whoo! -Whoo!

It feels weird going on a trip

with people that I'm not talking to.

I will not bring Jenna around somewhere

that you and Aaron are gonna be. -You already did.

This is a conversation that Michelle and I could have had

without you being involved and making it so much bigger--

[singsongy] Yeah, 'cause we would hold you accountable!

A word you can't stand!

LUKE: Hopefully I'm not bringing the ring back

'cause she said no. -It's a full carat.

She'll say yes. [laughs]

-[island style music playing] -DANNY: Maui.

-Happy place. -Operation Get Engaged.

Same reason?

Did you cross a line when I was married to Michelle?

***

* Either love me or leave me alone *

* Let my judgment say "each to their own" *

* But I'm better, but I'm better *

* This ain't my best, I'm better *

-Hello! -[indistinct conversations]

This is the perfect spot to kind of kick off our trip.

It's very Hawaii island vibes with the location and the view.

It's just perfect.

It's so beautiful.

Where's Luke and Kristen?

I was texting with Kristen, and she was like,

stuff isn't going good with his grandma.

Aw.

So, everything's just kind of upsetting him.

Hi, baby.

Okay.

When Luke is really frustrated, likes to take a walk.

He likes to take a drive

and deal with some of his emotions on his own.

But, like, come on, Luke, get it together.

We've had a stressful time recently,

and this is for us to enjoy.

Hi, guys. Can I get you started with anything to drink?

Casamigos Blanco skinny margarita

with salt, please. -We're going to get sake.

SERVER: Can I also take your, uh, dinner order?

-I'll do the filet. -Pan-seared King Salmon.

Okay, let's go, babe. I think they're waiting

on us for dinner. -Are they?

***

-[ice rattling] -Hi, guys.

Thank you. Ooh, yeah.

-We just need to go eat. -Okay.

-That's all. -Look at my mountain of edamame.

So, what did you decide to do for Cruz?

So, Zuly's staying at my house the entire time that we're gone,

and then Jax is just coming to my house

to play with Cruz...

-NIA: Yeah. Yeah. -...for now. Yeah.

This is my first real vacation

that Jax hasn't been on in, like, 10 years.

It feels very strange because everybody's coupled up,

but it also is very freeing. Like, thank God he did not come.

-Whoa. What is all this? -It's like a little bridge!

Here they are!

-[all cheering] -Yay!

Get over here, Kristen!

-How you feeling? -All right, I'm here.

Iced tea lemonade with Tito's, please.

I can tell that Luke's a little frazzled,

and I'm one of the few people that know

he's proposing to Kristen tomorrow.

So I'm hoping that Luke is gonna be able to keep it together

and keep the train on the track for tomorrow.

So it would be really nice if once in a while,

Janet would just acknowledge the fact

that she can be a really sh--ty person

and start a lot of things to be drama for everyone else.

And also, I mean, Janet yelled at me.

Where the [bleep] is my apology?

What? [laughs]

***

-Cheers to friendship. -Cheers to friendship.

[all cheering]

DANNY: Cheers to family.

Cheers to having each other's backs. [chuckles]

Does this feel awkward at all with Jesse here and stuff,

or has it been pretty, like, chill so far?

I think it's on him.

[indistinct conversations]

You know, there's sh-- that just can't be comprehended,

you know, childish.

Unwell behavior.

-Hit this real quick. -400 bucks.

-Hey, hey, hit this. Hit this. -I would say 400.

Useless.

I know I'm on the outside, but it seems like he's making

positive strides from now since last year.

Oh, no, he's gotten...worse.

-JASON: Oh, interesting. -Yeah.

Is everybody done? You guys should come back

and see my presidential suite.

Guys, I picked up this check. I got you guys.

Now everybody can watch my booty as I walk up here.

Hey, uh, Aaron, can you hold back with me for a sec?

Yeah, of course.

Just the two of us.

[indistinct conversations, laughter]

I don't have a choice with Jesse.

He's gonna be in my life forever,

even when Isabella gets married,

and Aaron doesn't have to deal with him and his toxicity.

So I do get scared sometimes that one day

Aaron's gonna be like,

"This is too much to deal with a crazy ex-husband."

-How are you enjoying yourself? -Very well.

-Yeah? -Yeah.

I figured it was probably time

that you and I had a little conversation.

There are issues that Aaron and I need to discuss.

We should have discussed them very early on. We didn't.

As a father of Isabella,

something that really bothered me,

and--and you wouldn't know this

'cause you're not a father.

Coming back on ----ing Father's Day

and having my mother and my friends

send me screenshots of you with my daughter

on Father's Day... -Yeah.

...that is disrespectful to post a picture of my daughter

without even asking her father if that's okay.

Right.

That was a big slap in the face from Michelle.

Completely slipped my mind. We were having such a good day,

you know, supporting her, and I put myself in your shoes.

And I was like, "Yeah, that's not right," so I took it down.

But, like, treat us with respect and...

Well, then let me ask you a question.

***

Did you or did you not

cross a line when I was married to Michelle?

[dramatic music playing]

Emotional, physical, in any way, did you cross a line?

***

No.

Absolutely not.

We texted here and there,

was once for that coffee meeting at Blackwood

and another time when I told her, "Hey, come to Runyon.

I'm selling honey."

But other than that,

we would run into each other all the time.

I'm thinking, this is bullsh--.

Listen, at this point, I wanna like you,

but she triggers me, and she has a way to get under my skin.

And I think it's kind of time to let it all go.

If we could just all somehow figure out a way

to, like, work together,

and you guys being here this week,

I mean, it should be the perfect ----ing time to do that.

[sighs]

I don't know. I think we've said enough.

In my heart of hearts,

I...1,000% think they had a physical

and emotional relationship before we separated.

How else do you explain having a boyfriend

two weeks after we separated while still living in my house?

Speak of the devil.

Everything okay?

Yeah.

You ready to go?

Yeah, I think we're done.

***

Coming up...

So you're gonna be mad at me.

What?!

Wait, so Danny and Nia got to be there, and we didn't?

* Let me get to know you better *

* Show you the good things in life *

* Let me treat you like my treasure *

Cheers! To Hawaii! Cheers, everybody!

-Love y'all. -Boom.

-Cheers. -Bow!

-Cheers. -Whoo!

Paradise.

* Let me be the one tonight *

Somebody spray tanned in there. Looks like a dead body.

[laughs] The sheets.

Yeah, I know. It's nasty.

I hope they change the sheets when we leave.

Yeah.

[singsongy] I'm so excited for today.

Great day for a great day, baby!

-Be a part... -Engagement day!

We're gonna be a part of a proposal.

We're a hundred percent sure it's gonna happen?

How is Luke doing? Like, he seemed like he was

doing really bad last night. -Yeah.

Last night, Luke had a moment, went off the rails a little bit.

I will give anyone at this table $20

to snort this ball of wasabi.

-I would do it for you. -[snorts]

-Aah! -[all exclaiming]

He was like, about to have, like, a mental breakdown.

Yes, I'm ----ing going through some sh--!

I just want you to be there for me.

That's all I want, Kristen.

KRISTEN: Luke, you don't have pants on.

You know, it's a really big moment in your life,

and you wanna get it right. So, I am sympathetic

to what he's going through right now.

But I talked to him, uh, this morning.

I said, "How you doing, brother?"

He seems like he's, uh, he's...coming back.

Okay.

-Have you talked to Kristen? -I haven't talked to her at all.

-Oh, yeah. -I talked--We talked to Kristen.

-I had breakfast with her. -Oh, yeah.

I have not talked to her since El Coyote.

You know, she's mad because I was trying to talk to her,

and you were just, like, yelling at her.

This is a conversation that Michelle and I could have had

without you being involved and making it

so much bigger and worse. -[singsongy] Yeah, 'cause we

would hold you accountable! -Janet, come on.

How did that night get so heated at El Coyote?

I understand the drinks were strong,

but how did it get so hot, and everybody was yelling?

There's a group of people who, every time the heat is on them,

suddenly there are these made-up rumors

that get thrown out. Jason was a victim of it.

Jason's in no...space

to be judging anyone's relationship.

Keep your wedding ring on all the time,

and then you can start talking.

You guys were the victim of it.

-I-- -I'm Aaron.

You're friends with Jenna Willis, right?

Or you know Jenna Willis.

It's a deflection to me.

At El Coyote, I felt like

Kristen was not taking any accountability and was like,

"I don't know why Jenna's around.

What are you talking about?" Just own it.

Just say, "I purposely brought this person around

'cause I don't like Michelle, and I wanna ruin

her happy relationship." -I just wanna be in the pool

with my hot boyfriend and have fun.

But my friends keep bringing up a girl he once hooked up with.

We're gonna get a couples massage.

AARON: On that note, we're gonna go get deep tissue massage.

-JANET: You guys deserve it. -Aw! Couples massage!

[singsongy] So sweet!

Why do we have to talk about her again?

Can we move on?

JANET: You guys are a really hot couple.

-Yeah. -MICHELLE: Thank you.

-AARON: Think so? -Yeah.

Michelle's really doing it for me in these little shorts.

I have a crush on Michelle, I've realized.

ZACK: Ugh. Our last day with this view, though.

-[Benji laughs] -Ugh.

Do we really have to give up this room to Kristen?

I don't think they really need it.

You know, their room's pretty, too...

for an engagement, I guess.

Also, I love that Jasmine today was like, "Something's amiss."

And I was like, "Just trust me. Just trust me."

And then she's like... [whispering]

[normal voice] I was like-- I was like, I can't. I can't.

This is a lot of sh--, like...

-For gay people setting up. -I mean, it's gonna be real.

-What can go wrong? -[grunts]

There we go. Oh, my God. It's literally so--

Oh, wait. And the T-shirts are like this.

Look how cute this is. [chuckles]

-It's super cute. -It's literally the best.

We had to get Janet and Jason's size

to make it seem like... -Yeah.

"Oh, we're getting, like, a group photo on a shirt"

or whatever, and I don't know what we're gonna do

with them tonight, 'cause I can tell you this.

If Kristen gets proposed to and then gets off the boat,

and Janet is standing there with a shirt of her face on it...

[laughs] -...that will be

the biggest meltdown in the history of the world.

Like, Chernobyl ain't got sh-- on what would happen.

But I feel like we should pack first.

-Yeah. -Because our sh-- is everywhere.

-[rhythmic knock on door] -KRISTEN: [singsongy] Hello!

Um, hold--hold on one second.

-We're naked. -Even better.

-[laughs] -Wait. That's so cute.

I said last night to him-- I was like,

"You should actually wear that tomorrow night to dinner."

Or I will.

Actually, let's just sit down for a second.

Zack. Here you go.

-[laughs] -I know they're yours

because I've seen them before. -'Cause they're...

And they're also massive. No, but last night, I felt like,

number one... [scoffs] Luke--I love that there's

someone more dramatic than you sometimes.

-Like, you have found dramatic. -He wasn't dramatic.

He--He was in his feelings and whatever.

But I'm just saying, like--

He had a really, really hard weekend.

-He literally just spent... -Yeah, it's--it is--

We spent 36 hours flying when he had to meet

his sick grandmother, who, in his mind, you know,

when you're about to--when you think you're gonna lose someone,

you go worst-case scenario. -Yeah. Okay, well, we need to

start getting ready, um, 'cause we have to shower and stuff...

-Okay. -...in our massive shower.

-[knock on door] -Hola.

-Hi, baby. -Hola.

Hi. How was golfing?

-Good. -Do you feel Zen?

LUKE: Last night was a disaster, but I got some good sleep.

I love Kristen so much.

Now I get to get down on one knee

and give her the best surprise of her life.

Babe, will you shave my neck? Can help me do it?

-Yeah. -I wanna get, like,

more ready today. -Yes.

You wanna look like less of a...

-Yeah. -...caveman.

LUKE: Yeah, I'm gonna trim this a little bit.

-ZACK: We'll see you guys later. -Yeah, I'm not--and I'm not

showering before fishy time. -Okay.

'Cause I feel like I'm gonna probably stink, like, fish

or something, and then I'll shower after.

-I don't know what happens-- -No, you're not going to.

-You should shower before. -Why?

Because I think we're going to the luau right after.

-Yeah. -I don't think there's gonna be

time to shower and get ready after.

No, you don't need to shower every day in Hawaii

if you're in the ocean. [snorts]

[chuckles]

-Bye. -It's true.

I've been trying to, like, really subtly text her

about being cute.

Ugh, I love her so much with her inspo pics.

Just, I want you to--

It's like a boat with a bunch of gross fish guts on it.

-So, it's just like-- -No. No, it's not.

-No. -Sent this inspo photo?

-Honey, it's a kissing photo. -Oh, my gosh!

All these look like they just got engaged.

-Just a boat. Yeah. -Great.

I feel pretty dressed, then.

I'm excited. I'm anxious.

The boat's reserved. Danny and Nia are coming.

Zack's handling everything at the resort.

Kristen not wanting to shower was not on my radar.

Coming up....

Is that the only time you guys broke up?

-Yeah. -Well, there was one more time.

When you started dating her.

***

Hey, hurry, hurry, hurry. It's hot, it's hot, it's hot!

Hurry, hurry, hurry, hurry, hurry!

[birds chirping]

You all right? Mwah.

***

JAX: I'm really, really happy that I get to see Cruz today.

It's been seven days since I've gotten out of the facility

and was really worried because I was gone for so long

that I thought he was gonna forget about me.

Not seeing your little boy is just--

it's gut-wrenching. It is gut-wrenching. And...

[exhales deeply]

***

He's my everything.

And, you know, he picked up right where we left off.

I mean, he's the best medication I have right now.

Thank you.

* Do I worry? Do I care? *

* There's no place for... *

Hula really is a storytelling art form that allows a person

to use the hand, feet, and body to manually unfold a story.

Lord, what would my hula dance be?

One, two, pick the shell.

Obviously it has a lot to do with Jax.

So, I'm thinking I can just rip off his nuts,

pull them out, and throw them in the ocean.

That's like a good hula move. [laughs]

I don't know what this is, but it looks like The Hulk.

I don't know if it's a shaved ice

or a shaved ice cocktail or if it's a different thing.

I don't need to be buddy-buddy with Aaron.

-BOTH: Cheers. -I think you start with a straw

and you end with a spoon. -Oh, this...

But I have to do what's in the best interest of Isabella,

and Isabella says she loves Aaron.

Bye! Love you. Love you. Love you!

-Love you, too. Bye. -Bye.

Then I have to respect that. Easier said than done.

Speaking of shaved ice, when's the last time you played hockey?

You sure you wanna go there?

-Is this a sore topic? -[laughs] Yeah.

"When's the last time you played hockey?" Oh, really?

It connects us. It connects us even more.

The last time I played hockey, it was probably...2016.

I got buried in the corner.

I had the worst concussion of my entire hockey career.

I checked myself into Cedars,

and Michelle and I hadn't been dating for a few weeks.

I had an option of, like,

who to call to pick me up at the hospital.

And, uh, that's kinda how Michelle and I started back up.

Were you gonna-- if that didn't happen,

would you have? -No.

[laughs] Uh, yeah, I guess I've been concussed

for eight and a half years.

Was that the only time you guys broke up?

Yeah.

JASON: Well, there was one more time.

-When you started dating her. -[laughter]

Technically, Michelle and I are still together. Right, lawyer?

***

That must feel real good.

Technically, they were in a relationship

while she was still sleeping in my bed.

And, uh, yeah, I'll take a few digs when I can.

JASON: You guys spoke for a while yesterday.

I saw when you came back to the room, you guys did

a little beers toast, so I assume everything's pretty good.

I think it was a good talk.

Yeah. How do you feel about last night?

I thought it was good. Um...

And like I said, just be on my team.

I will do my part as a promise to you

to not be calling her a lying, cheating whore

because she doesn't deserve that.

She's the mother of my child.

I trust that you are a man who will respect my daughter,

a man who will now respect me.

And if you have a question about my daughter,

you will reach out to me.

Those things alone, we can build a foundation on.

-Respect is a 2-way street. -Right.

The problem is, even if he respects me, Michelle doesn't.

So, if he says to himself,

"I don't feel comfortable with this. I should call Jesse,"

Michelle says, "[bleep] Jesse," what is he gonna do?

Be like, "No, [bleep] you, Michelle.

Me and Jesse are bros"? It's never gonna happen.

So, moving forward, we just see how it goes.

-[cellphone rings] -[laughs]

Put this on quick.

[ringing continues]

Oh, my God.

-Hello. -JAX: What's up, man?

I'm with my best friend and my new best friend.

-Look at this ----ing loser. -We miss you, buddy.

Aaron and I are, uh, Kumbaya.

He gave me a couples massage at the beach.

-[laughs] -How you feeling?

Yeah?

You love Cruz time?

It's not as good without you, brother. You need to get back.

[laughs]

-Later. -All right.

Coming up...

NIA: This is the light. This is a good light.

* My love is here for you *

* Just me *

Whoo, look at the tails.

Some big fish they've caught.

We're catching this one today.

DANNY: That's crazy.

MAN: How's it going, you guys?

Right on. Welcome on board. Watch your step.

-Dana. -Good to meet ya.

-Welcome aboard. -Oh, yeah, yeah.

LUKE: Look at the rays. Look at the stingrays.

-[gasps] Cool! Oh, my God! -DANNY: Wow.

And they're having sex right now.

Maybe it's good luck. They're making babies.

LUKE: This is a baby-making trip.

NIA: Guys, we're already seeing nature.

KRISTEN: Make love. Have those babies.

I didn't even know stingrays did hump.

Wait, do eagle rays have, like, a penis that sticks out?

I don't know.

I love Mother Nature.

MAN: Okay, we're gonna go-- we're gonna go ahead and--

and take off. -Oh, I thought we were gonna...

Making moves, baby!

* Ride up in from the west end *

KRISTEN: How beautiful the ocean color is!

* She gon' bring her best friend *

Oh, yeah.

LUKE: I think I need to take my luck to the back, though.

KRISTEN: Okay.

***

-So, when the time comes... -Yeah.

I'm gonna get us up front, and then I'll say,

"I'll grab my hat real quick. I'll be right back."

Okay. Yeah. And that just tells me I gotta get up,

get the phone out. -Get your phone out

and make sure Kristen doesn't follow me back here.

Gotcha, gotcha. If she asks, be like, you're coming back.

If she rides you, be like, "He's coming right back.

-Yeah, yeah. Got it. -Yeah, yeah.

-Perfect. Perfect. -We'll be good.

DANNY: Come on, baby! Come to Papa!

What do you wanna bet? 20 bucks on first fish?

-I was gonna say something. -You in?

-I'm in. -Let's go, Nia!

Whoo-hoo!

She has one on?

NIA: I see it. Nemo?

MAN: Oh, almost like-- that's like the Disney movie.

-You've heard of "Moana"? -Uh-huh.

That's what it's called. It's called Moana

Nia! That's so not nice of you.

I think they ended up keeping her for a while

and using her as bait for bigger fish.

[music warps down]

How sad is that?

Whoo-hoo-hoo-hoo!

Cool.

$20, baby!

You wanna see my boobs? Will that help?

[chuckles]

Right now my head is not with the fish.

I am not thinking about catching a fish

bigger than Danny's little thing.

Show me the money!

We need--You and I need to take photos.

Okay.

Just, like, cutesy swimsuit, girly.

How are we not taking any photos?

No, because I'm not feeling cute at all right now.

When the--we'll find a spot in the shade.

I'm feeling sweaty and absolutely disgusting.

I just, like, have all these photo plans in my head,

and we haven't taken any.

Oh, my God, is it hot. Oh, my God, is it humid.

Like, I'm sticking to my own self right now.

NIA: Are we feeling good for photos?

[groans]

I can't really see straight.

Do I wanna be taking pictures right now? No.

Do I ever wanna be taking pictures? No.

[sighs]

Let's get picture-ready and snap some...

"schnap" some pics.

I have no idea what I look like right now. [chuckles]

Wow.

NIA: See, this is the light. This is a good light.

LUKE: No, she's sitting on my bag.

DANNY: [lowered voice] Oh, my God.

This is typical Kristen.

I'm gonna wait till she gets up.

We're at the finish line, and she's sitting on the ring.

Jeez-o-Petes.

Hey, Kristen, I know photos are not your thing, but we have,

like, three minutes for, like, perfect lighting.

I'm going as fast as I can.

The stress I feel right now about taking

these picture-perfect, like, couple-y photos

is gonna, like, make me have a meltdown.

Like, I'm trying. The makeup's on.

Like, the tits are out. I'm doing the best that I can.

-NIA: Yeah, perfect. -I'm gonna go the opposite way.

-Okay. -When she comes out

and goes around, I'm gonna go the opp--

You're gonna go the opposite. Okay.

-And snag it. -Perfect.

Shove it in my pants. [chuckles]

-Okay, she's going around... -NIA: Perfect.

...the other way.

-Are my sunglasses up there? -Just mine.

-No? -Um...

Now I have to pee.

Can you take a few pictures for me and Daniel?

-Absolutely. -Thank you.

-Before my phone dies. -Yes.

Okay. I think this is good lighting.

***

-What? Yeah? -Looks good.

Okay. Yeah, that's really pretty.

Okay, take some for us. and we'll take some for you.

Stop talking. Good.

So cute. So cute. So cute.

I took, like, 40 million.

Thank you. And the lighting is so pretty.

-Okay. -LUKE: Uh, over there, right?

-The light? -KRISTEN: Yeah.

NIA: Yeah, the light's good over there.

-Wherever, wherever, whatever-- -Come here. Come here.

-Just do what Nia says. -Come here, come here.

-[laughs] -Snap. Snap. Now snap.

I think there's some dolphins over there right now, dude.

-Are you being for real? -Yeah.

Wait a second. Come here.

-There's like a pod. -Where, where, where?

Where the splashes are? No, that's the wrong--

-NIA: No, hold on. Right there. -See that edge right there?

-Look right here. -Okay. Hold on.

-I feel like I saw it splash. -Look straight out.

Hold on. Straight. What does straight mean?

See where, like, the circle is in that--in the cliff?

-It's like... -Yes.

...probably 50 yards in front of that.

-But not where it's splashing? -Right.

LUKE: Your butt looks so good from this angle.

-[laughs] -Hey, baby.

We've had some awesome adventures, honey.

-Come here. -Yeah. What are you doing?

-What the [bleep]? -[music warps down]

Will you be the catch of my lifetime, baby?

[whispering]

I love you so much. We've had such incredible adventures

and so many new experiences.

I wanna spend the rest of my life with you.

Will you marry me?

***

Are you being serious? It's real life?

***

-[laughs] -Here, put it on.

Here. Put it on.

-I didn't see that. -[laughs]

I'm nervous, too.

***

KRISTEN: Luke is very much my rock.

I mean, he stands by me. He stands up for me.

I love that he's exactly who he is

and lets me be exactly who I am.

I love how funny he thinks he is, but he's not.

Like, that is my partner in crime.

That is my ride or die. This was the easiest yes I've ever said.

-[laughs] -Aah! You're getting married!

Congratulations! You're engaged!

NIA: Whoo!

Whoo-hoo! Oh, my gosh!

[Danny laughing]

***

You're mine forever.

[laughs]

I'm just so happy.

[Danny and Nia cheering]

-Were there really dolphins? -LUKE: No.

Oh. [laughs] I would have stood there forever.

* My love is here for you *

* Just me *

ZACK: Oh, look at that. You packed for me.

I knew you were a good boyfriend.

I knew I started dating you for some reason.

Okay, let's grab all the stuff in here.

They literally put stuff in every ----ing drawer.

How much golf did he think he was gonna do?

Oh, [bleep]. There are more drawers here.

Luke, you knew that I would be switching

Kristen and Luke's room with mine and Benji's room.

No! She put stuff in-- Ugh!

Why is there stuff in every ----ing drawer?

I can't with straight men.

-Do you have everything? -I think so.

Is that yours, or is that Jesse's?

I don't wanna touch that if that's Jesse's.

Those are not mine.

Okay, well, whatever. I've already seen his butt.

Might as well touch it, too. Oh, hello, sir. Oh--

***

I guess I... [whispering]

BENJI: Oh. [chuckles]

So, just add to the list of my problems--Jesse.

Um, so because we-- we didn't realize

you were gonna be back in the room,

so I'm just gonna have to tell you now instead of later.

Um, Luke is proposing to Kristen.

-Really? -Literally tonight.

-No ----ing way. -Yeah. Well, actually...

-Is that why he-- -Not tonight. Like, right now.

That's why he was so--yeah. Right now they're on the boat.

That's why nobody else could go fishing

and everything else-- -Who the [bleep]

wants to go fishing? -Well, I don't either.

I wouldn't have wanted to go either way, so let's be real.

You're just gonna have to put some earmuffs on.

So I say, why don't we call the hotel

and get...

500 white roses...

-[music warps down] -...and 500 hibiscus petals

and put 'em all over the whole place?

-Wow. -[laughs]

Can we get, like, 5,000 white flowers?

Jesus Chr-- I'm like, why--

Michelle says he's broke.

-He is the one who is broke. -Exactly.

He cannot pay for rent.

And you're a loser! You ----ing spend all of our money.

So I guess he's just gonna put it on the credit card?

[line rings]

Hi, um, we're in the presidential suite.

Uh, I have a question for you. Is there somebody that could

get me a thousand hibiscus flowers?

***

[busy signal beeping]

What is going on?

BRITTANY: Do you think we could room service shots?

-Yeah, we could-- -We--We should--

JASON: You want me to just-- I'm already ready.

You want me just go down and buy a bottle of tequila?

-Yes. Yes. -Thank you. Please.

That's probably, like, cheaper.

JANET: This is why Jason's in the girl room.

All right, babe. So, are we wearing

the blue dresses tonight? -[faucet turns on and off]

-Yeah. -Or do you want to do color?

I think I'm gonna wear my blue.

I just wanna look-- I don't wanna look crazy.

Like, this is Kristen's, like, engagement.

Like, we're gonna see this forever.

Like, what if she said no?

-I know. -No, she's gonna say yes.

But, like, I'm just surprised that, like, no one else knows.

I mean, I figured it out because I was like,

"Zack, why aren't you hanging out with me?"

I don't think anybody else, though, figured it out.

I don't think anybody else knows.

Actually, tonight is actually secretly our engagement.

-What? -Mm-hmm.

-What do you mean? -It's ours.

-Shut up. -[chuckles]

-It's a double engagement? -It is. It is.

I would die, Melissa.

I would literally punch you in the--

-I might punch you in the face. -Yeah?

-Yeah. [laughs] -Okay.

We should probably get dressed, though, because I think--

Okay, good. Oh, we're good. Okay.

[island-style music playing]

[bottles clink]

Okay, so first thing I'm noticing is we're not

doing balloons out here. -Uh, no.

-They will fly away. -[laughs]

This is the--Oh, my God, this is such a perfect--

-Aloha! Welcome! -Hey, how are you?

-Hello. -We're so excited you're here.

Oh, my God. Wait, hold on. Let me put this down real quick.

Your friends are gonna be gathering together.

So what, um, do they-- is it, like, already set up?

Are we good to go on the bar?

Well, he's still setting up.

We're gonna need to get glue for that, or tape.

That's okay. I'll get weights or something for it.

Is way windier than I thought it was gonna be.

Okay. Guess I probably should tell other people

that this is an engagement party now.

The proposal's supposed to happen at sunset,

so now as the sun's going down, I can finally call everybody,

let them know there's actually an engagement happening.

And she better have said yes, 'cause I put...

[clenching teeth] way too much work into this.

Brittany's gonna be so mad at me. Literally, so mad at me.

[line rings]

-BRITTANY: [singsongy] Hello? -Hello!

So you're gonna be mad at me.

What? Is Jax here? [laughs]

ZACK: [over speakerphone] Oh, God, no! I--okay, I would

never surprise you with that. That is not a surprise.

-Okay. -Um, no.

Luke just proposed to Kristen.

What?! He did?!

ZACK: Yeah. Are you, like, so shocked?

Uh, yeah. Wait, so Danny and Nia got to be there, and we didn't?

ZACK: Luke wanted it to be, like, such a surprise.

You know, Danny and Nia being there, like, yes,

she loves them, but, like, if you and I were

on this fishing boat, do you think that makes sense?

Uh, yeah, I was trying to go fishing the whole time. [laughs]

Oh, well, maybe you, but I'm like, I'm not even a fisher.

BRITTANY: I cannot help but feel a little bit left out.

Kristen is one of my very best friends.

She's literally a sister to me, and I would have loved

to have been there and been in that moment.

And, like, I feel like all these other people

knew about it but me.

It just doesn't really make sense to me.

-ZACK: Love you. Get ready. -All right.

-And I will see you soon! -All right.

[singsongy] I'll see you soon! Bye, baby.

-Okay, love you. Bye. -Bye.

Hey, Janet, Michelle.

MICHELLE: Do you see how much hair I have?

-Guys. -Hmm?

So, I just overheard Zack telling Brittany

Luke and Kristen are engaged now.

-Aw! -What?

-He just proposed. -Yeah.

-Oh, my God. -I didn't--I mean,

I didn't know that was-- Did you guys have any idea?

-JANET: On that boat today? -No.

-That's cute. -I don't know where they did it

or what. I just overheard it. I fully eavesdropped.

-I mean, I don't know. -[laughs]

Oh, [bleep]. [bleep].

Now we've left our child for the first time

for the longest time we've ever left him,

and it's for Kristen's engagement trip.

If it's gonna be a big group dinner,

and they're gonna go, I'm gonna bow out.

Just give Zack a call now to see if that's the whole thing.

Yeah.

Um, let's do a shot together.

Are you allowed to drink on the job?

No, no, no, no. I don't drink, but our shot has a little

ice cube in it for the bar. -Ooh, let's do that.

-[cellphone rings] -So sorry. Hold on one second.

-Hello? -Hi.

-Hey. -I heard, um,

you told Brittany the news. Like, congratulations.

I'm super happy for them.

Feel like maybe Jason and I shouldn't come to dinner

'cause it's been kind of weird.

Has Kristen Doute ever apologized for anything

in her ----ing life? No. She's sorry that she got caught.

No. She's doing the dirty work.

This is a conversation that Michelle and I could have had

without you being involved and making it

so much bigger and worse. -[singsongy] Yeah, 'cause

we would hold you accountable!

Well, I wanted to do this in person

because I don't want you to think that, like,

I'm dis-cluding you, 'cause I'm not.

-And I don't think-- -JANET: No, that's totally fine.

I actually--I think it'd be best if we don't come.

Okay. Um...I got T-shirts made.

I think it would be a little aggressive if

you had a shirt on with their faces on it,

and you guys haven't even, like, talked out

the things that have happened. -Yeah. Yeah, for sure.

But I wanted to say that, like, the dinner aspect,

it's a stand-up dinner.

It's, like, in a very open area down by the pool

with hors d'oeuvres.

So, I feel like you coming shows that, like...

you do wanna work on things.

You are happy for them 'cause I know you are, and I think it--

JANET: I know. I'm so happy for them.

This weekend should be about them celebrating,

and they should honestly just have the best time.

ZACK: Thank you very much for that.

I was kind of nervous to have this conversation, but--

-No, it's totally fine. -I really appreciate--

-Okay. -It's totally fine.

Send my best, and we'll see you guys tomorrow to celebrate.

-Okay, great. -Have a great night. Bye.

ZACK: Okay.

Where do you wanna go to dinner?

[stifles laugh] Okay, well, now I...I'm off the hook.

Okay. This was great.

JANET: All right, we're going to dinner.

I don't want Kristen to come out to a celebration

where she's looking around the room

and seeing everybody that makes her smile,

that she feels like has been supportive of her relationship,

and then see me and feel dread.

We're gonna talk to everybody back in L.A.

BRITTANY: Wait, you're not-- What do you mean?

What do you mean, back in L.A.?

I'm not gonna hang out tomorrow either.

I mean, just because Kristen, you know, went

for my marriage and Jesse and Michelle's marriage

doesn't mean that she doesn't deserve

to have a happy engagement celebration.

Well, if we're gonna be excluded from one thing,

I'm not gonna jump in anything else.

First of all, we weren't excluded from dinner tonight.

-But-- -But here's--it's a good thing

that they got engaged, but it does make sense if there's,

like, weird tension between, like, Janet and Kristen, so...

-And this trip's for them. -But we, um--

What do you mean this trip's for them?

Well, this trip's for their engagement now.

You know what I mean? Like, this is--it's always gonna be that.

So I'd rather just, like--like, I don't want it to be weird.

I haven't spoken to Kristen here.

Janet, I'm literally taking off work to be in Hawaii. It's not--

-This trip's for us as well. -I know.

So let's do our own stuff tomorrow.

I feel weird that this is happening.

No, it's good. No, no. I wanna just go get food

'cause I'm hungry. -Yeah.

[laughs] And I thought we would be eating by now.

I feel weird in my room right now. [laughs]

If I was Janet, I wouldn't wanna go either.

I wouldn't want to wear a T-shirt and be like,

"Congratulations. We don't get along!" You know?

It just has to feel super awkward for her.

I'm not gonna go to that and TBD on tomorrow.

I don't know this tomorrow thing. Stop saying that.

I--This is--okay. We'll figure out tomorrow when it comes.

What does it matter if they're engaged?

We'll figure out tomorrow when it comes.

I just am ready to-- I'm--I've been starving.

Just, like, slow down and not making these decisions

without talking to me.

I've been starving for hours. Can we go get food?

***

* I'm gon' try to talk *

* Yeah, ain't nobody gon' stop me *

* Don't come to talk, yeah *

But I want the "I love you," so I have these two.

"I love you." Okay? So, I think it should just be...

Or should I put these in the room?

I should just put these in the room.

-That'll make it easier. -Great.

Are you having a panic attack right now?

-Yep. -What is happening?

Myself, as a functioning panic attacker

would suggest that Zack maybe scream into a pillow.

[muffled scream]

I personally recommend Xanax.

Guys, we're not ready.

-Oh, my God! What? -Oh, my God. How cute.

-[laughs] -I'm engaged!

So happy!

I would have helped. Thanks, guys.

I just don't know why they didn't include me

out of everybody in this crew.

Oh, I just wanted to be able to help with that situation

and made something special for Kristen, but whatever.

I'm being selfish.

But this is super cute.

-Everybody, guys, guys... -Oh, there you are.

Okay, quickly. Yeah, I need to finish.

If you could just find your size.

You're just gonna put this on...

-Okay. -...for when they get here,

and then you can take it off. -Okay.

And then we're gonna use it tomorrow for the boat day.

Okay, I'm going.

Is your arm tired yet?

-Nope. -[laughs]

Not at all. Don't you worry.

-Oh. -Ask me when I'm 99.

Whoop-whoop.

She's coming. She's coming. She's coming. She's coming.

-Really? -Do we have the...

-Hurry up! Run! -Hurry!

-DANNY: What a day, guys! -NIA: What a day!

You became a fiancée today.

-Wait. I want a red rose! -He said--wait.

Zack told us that he wants us here.

-Sit here. Here, here. -Oh, yeah, yeah. Over here.

-Over here, over here. -Brittany, this side.

KRISTEN: Oh, my God. I haven't said a word yet.

-[whispers] Wait, wait, wait. -No, after she opens the door.

Shh!

-[cheering] -Oh, Jesus Christ!

[cheering continues]

Whoo!

-Whoo! -Whoo!

-Yeah! -Yes!

[cheering continues]

-Look at those shirts. -Oh, my...

Look at the T-shirt.

Wait, you did it. You guys did this, then.

-Me and Zack. -Oh, yeah.

Like, to go above and beyond like this,

have all these decorations

and to have all of these shirts printed

and to keep it a surprise, like... [gasps]

It's really sweet.

[laughs]

Congratulations.

Congrats.

Congrats. Love you guys.

I know. I was totally shocked.

Okay, if we could just present Mr. And Mrs. Broderick. Yay!

[cheering]

-Whoo! -We're not married yet.

-Put it on them, Zack. -[laughter]

You can just feel, like, the energy and, like, the love,

and you know that it's, like, real, and you know

it's gonna last and it's just, like, perfect match.

A little jealous. No, I'm just kidding.

No, I'm happy for them.

I don't think anyone would do this

intentionally or maliciously,

but we haven't had a chance to talk to our family.

So, please don't post any Stories tonight or anything.

-Don't tell anyone. -We don't want them to find out.

It's your moment. You define your moment.

-We love you guys. -Also so while we're doing this,

um, we have two surprises for you.

Number one, um, I swapped your rooms.

So the presidential suite was actually for you.

And he did know that. So...just FYI--

I have to share a shower with you guys.

-Just...it's no big deal. -ZACK: That's the only caveat.

-We apologize in advance. -That's the only caveat.

[cork pops]

Whoo!

Congratulations!

Okay. And then we have hors d'oeuvres downstairs.

Blah, blah, blah. Okay, great. Now let's do champagne.

[cheers and laughter]

I wanna thank you all for being here.

It means--means a lot.

Love you guys. I'm so happy for you.

-LUKE: Thank you. -So ----ing happy.

As someone who has been engaged and married before,

listen to your gut always. [laughs]

You have a new family, and I love you guys.

Cheers to you guys.

-Yes. -I love love.

When you get in that moment with somebody

that's, you know, your best friend

that you're intimate and affectionate with,

yeah, it's great.

-Thank you. Yeah, seriously. -Sorry if anybody that wanted

to go fishing didn't get to go. We didn't catch anything,

so don't worry. -I wanted to go fishing!

-Well, no! You did! -I caught a fiancée.

-You did catch something. -I caught a fiancée.

I'm really the luckiest girl in the whole world.

A trip to Hawaii, a new fiancé,

and literally the best friends a girl could ever ask for.

Yes.

I've never been so happy that I took a shower in my life.

-Cheers. -Cheers!

Future Mrs. Broderick right here.

[glasses clinking, cheering]

ZACK: Or is it future Mr. Doute?

-KRISTEN: No. -[laughter]

Next time on "The Valley"...

Ooh, cute boat.

"Pride of Maui."

Yay! We're movin'.

I talked to Brittany this morning about it.

I go, "I know you want this divorce.

Can we put a pin in it, maybe?" -I don't think that's a good--

-That's a bad idea? -Yeah, that's a bad idea.

Are there any repercussions for Janet being a complete psycho?

I know who Jason is. I know he would never do the things

that you were accusing him of.

ZACK: I specifically--exactly. And it's, like...

Why are we protecting the wrong people?

Nobody's protecting anybody! We just want the truth!

KRISTEN: Get the [bleep] off my boat!

It's my ----ing engagement weekend!

How about that, bitch?

Can't find what you're looking for?
Get subtitles in any language from opensubtitles.com, and translate them here.